@@ -57,7 +57,7 @@ KateViewInternal::KateViewInternal(KateView *view, KateDocument *doc)
   , editIsRunning (false)
   , m_view (view)
   , m_doc (doc)
-  , cursor (doc, true, 0, 0, TQT_TQOBJECT(this))
+  , cursor (doc, true, 0, 0, this)
   , possibleTripleClick (false)
   , m_dummy (0)
   , m_startPos(doc, true, 0,0)
@@ -94,7 +94,7 @@ KateViewInternal::KateViewInternal(KateView *view, KateDocument *doc)
   //
   // scrollbar for lines
   //
-  m_lineScroll = new KateScrollBar(Qt::Vertical, this);
+  m_lineScroll = new KateScrollBar(TQt::Vertical, this);
   m_lineScroll->show();
   m_lineScroll->setTracking (true);
 
@@ -116,14 +116,14 @@ KateViewInternal::KateViewInternal(KateView *view, KateDocument *doc)
   m_lineLayout->addWidget(m_dummy);
 
   // Hijack the line scroller's controls, so we can scroll nicely for word-wrap
-  connect(m_lineScroll, TQT_SIGNAL(prevPage()), TQT_SLOT(scrollPrevPage()));
-  connect(m_lineScroll, TQT_SIGNAL(nextPage()), TQT_SLOT(scrollNextPage()));
+  connect(m_lineScroll, TQ_SIGNAL(prevPage()), TQ_SLOT(scrollPrevPage()));
+  connect(m_lineScroll, TQ_SIGNAL(nextPage()), TQ_SLOT(scrollNextPage()));
 
-  connect(m_lineScroll, TQT_SIGNAL(prevLine()), TQT_SLOT(scrollPrevLine()));
-  connect(m_lineScroll, TQT_SIGNAL(nextLine()), TQT_SLOT(scrollNextLine()));
+  connect(m_lineScroll, TQ_SIGNAL(prevLine()), TQ_SLOT(scrollPrevLine()));
+  connect(m_lineScroll, TQ_SIGNAL(nextLine()), TQ_SLOT(scrollNextLine()));
 
-  connect(m_lineScroll, TQT_SIGNAL(sliderMoved(int)), TQT_SLOT(scrollLines(int)));
-  connect(m_lineScroll, TQT_SIGNAL(sliderMMBMoved(int)), TQT_SLOT(scrollLines(int)));
+  connect(m_lineScroll, TQ_SIGNAL(sliderMoved(int)), TQ_SLOT(scrollLines(int)));
+  connect(m_lineScroll, TQ_SIGNAL(sliderMMBMoved(int)), TQ_SLOT(scrollLines(int)));
 
   // catch wheel events, completing the hijack
   m_lineScroll->installEventFilter(this);
@@ -131,7 +131,7 @@ KateViewInternal::KateViewInternal(KateView *view, KateDocument *doc)
   //
   // scrollbar for columns
   //
-  m_columnScroll = new TQScrollBar(Qt::Horizontal,m_view);
+  m_columnScroll = new TQScrollBar(TQt::Horizontal,m_view);
 
   // hide the column scrollbar in the dynamic word wrap mode
   if (m_view->dynWordWrap())
@@ -142,8 +142,8 @@ KateViewInternal::KateViewInternal(KateView *view, KateDocument *doc)
   m_columnScroll->setTracking(true);
   m_startX = 0;
 
-  connect( m_columnScroll, TQT_SIGNAL( valueChanged (int) ),
-           this, TQT_SLOT( scrollColumns (int) ) );
+  connect( m_columnScroll, TQ_SIGNAL( valueChanged (int) ),
+           this, TQ_SLOT( scrollColumns (int) ) );
 
   //
   // iconborder ;)
@@ -151,13 +151,13 @@ KateViewInternal::KateViewInternal(KateView *view, KateDocument *doc)
   leftBorder = new KateIconBorder( this, m_view );
   leftBorder->show ();
 
-  connect( leftBorder, TQT_SIGNAL(toggleRegionVisibility(unsigned int)),
-           m_doc->foldingTree(), TQT_SLOT(toggleRegionVisibility(unsigned int)));
+  connect( leftBorder, TQ_SIGNAL(toggleRegionVisibility(unsigned int)),
+           m_doc->foldingTree(), TQ_SLOT(toggleRegionVisibility(unsigned int)));
 
-  connect( doc->foldingTree(), TQT_SIGNAL(regionVisibilityChangedAt(unsigned int)),
-           this, TQT_SLOT(slotRegionVisibilityChangedAt(unsigned int)));
-  connect( doc, TQT_SIGNAL(codeFoldingUpdated()),
-           this, TQT_SLOT(slotCodeFoldingChanged()) );
+  connect( doc->foldingTree(), TQ_SIGNAL(regionVisibilityChangedAt(unsigned int)),
+           this, TQ_SLOT(slotRegionVisibilityChangedAt(unsigned int)));
+  connect( doc, TQ_SIGNAL(codeFoldingUpdated()),
+           this, TQ_SLOT(slotCodeFoldingChanged()) );
 
   displayCursor.setPos(0, 0);
   cursor.setPos(0, 0);
@@ -182,21 +182,21 @@ KateViewInternal::KateViewInternal(KateView *view, KateDocument *doc)
   dragInfo.state = diNone;
 
   // timers
-  connect( &m_dragScrollTimer, TQT_SIGNAL( timeout() ),
-             this, TQT_SLOT( doDragScroll() ) );
+  connect( &m_dragScrollTimer, TQ_SIGNAL( timeout() ),
+             this, TQ_SLOT( doDragScroll() ) );
 
-  connect( &m_scrollTimer, TQT_SIGNAL( timeout() ),
-             this, TQT_SLOT( scrollTimeout() ) );
+  connect( &m_scrollTimer, TQ_SIGNAL( timeout() ),
+             this, TQ_SLOT( scrollTimeout() ) );
 
-  connect( &m_cursorTimer, TQT_SIGNAL( timeout() ),
-             this, TQT_SLOT( cursorTimeout() ) );
+  connect( &m_cursorTimer, TQ_SIGNAL( timeout() ),
+             this, TQ_SLOT( cursorTimeout() ) );
 
-  connect( &m_textHintTimer, TQT_SIGNAL( timeout() ),
-             this, TQT_SLOT( textHintTimeout() ) );
+  connect( &m_textHintTimer, TQ_SIGNAL( timeout() ),
+             this, TQ_SLOT( textHintTimeout() ) );
 
   // selection changed to set anchor
-  connect( m_view, TQT_SIGNAL( selectionChanged() ),
-             this, TQT_SLOT( viewSelectionChanged() ) );
+  connect( m_view, TQ_SIGNAL( selectionChanged() ),
+             this, TQ_SLOT( viewSelectionChanged() ) );
 
 
 // this is a work arround for RTL desktops
@@ -420,7 +420,7 @@ void KateViewInternal::scrollPos(KateTextCursor& c, bool force, bool calledExter
 
     Q_ASSERT(lines >= 0);
 
-    if (!calledExternally && QABS(viewLinesScrolled) < lines)
+    if (!calledExternally && TQABS(viewLinesScrolled) < lines)
     {
       updateView(false, viewLinesScrolled);
 
@@ -456,7 +456,7 @@ void KateViewInternal::scrollColumns ( int x )
   int dx = m_startX - x;
   m_startX = x;
 
-  if (QABS(dx) < width())
+  if (TQABS(dx) < width())
     scroll(dx, 0);
   else
     update();
@@ -1216,7 +1216,7 @@ void KateViewInternal::moveEdge( Bias bias, bool sel )
 void KateViewInternal::home( bool sel )
 {
   if (m_view->m_codeCompletion->codeCompletionVisible()) {
-    TQKeyEvent e(TQEvent::KeyPress, Qt::Key_Home, 0, 0);
+    TQKeyEvent e(TQEvent::KeyPress, TQt::Key_Home, 0, 0);
     m_view->m_codeCompletion->handleKey(&e);
     return;
   }
@@ -1257,7 +1257,7 @@ void KateViewInternal::home( bool sel )
 void KateViewInternal::end( bool sel )
 {
   if (m_view->m_codeCompletion->codeCompletionVisible()) {
-    TQKeyEvent e(TQEvent::KeyPress, Qt::Key_End, 0, 0);
+    TQKeyEvent e(TQEvent::KeyPress, TQt::Key_End, 0, 0);
     m_view->m_codeCompletion->handleKey(&e);
     return;
   }
@@ -1687,7 +1687,7 @@ int KateViewInternal::lineMaxCol(const KateLineRange& range)
 void KateViewInternal::cursorUp(bool sel)
 {
   if (m_view->m_codeCompletion->codeCompletionVisible()) {
-    TQKeyEvent e(TQEvent::KeyPress, Qt::Key_Up, 0, 0);
+    TQKeyEvent e(TQEvent::KeyPress, TQt::Key_Up, 0, 0);
     m_view->m_codeCompletion->handleKey(&e);
     return;
   }
@@ -1754,7 +1754,7 @@ void KateViewInternal::cursorUp(bool sel)
 void KateViewInternal::cursorDown(bool sel)
 {
   if (m_view->m_codeCompletion->codeCompletionVisible()) {
-    TQKeyEvent e(TQEvent::KeyPress, Qt::Key_Down, 0, 0);
+    TQKeyEvent e(TQEvent::KeyPress, TQt::Key_Down, 0, 0);
     m_view->m_codeCompletion->handleKey(&e);
     return;
   }
@@ -1889,7 +1889,7 @@ void KateViewInternal::setAutoCenterLines(int viewLines, bool updateView)
 void KateViewInternal::pageUp( bool sel )
 {
   if (m_view->m_codeCompletion->codeCompletionVisible()) {
-    TQKeyEvent e(TQEvent::KeyPress, Qt::Key_PageUp, 0, 0);
+    TQKeyEvent e(TQEvent::KeyPress, TQt::Key_PageUp, 0, 0);
     m_view->m_codeCompletion->handleKey(&e);
     return;
   }
@@ -1938,7 +1938,7 @@ void KateViewInternal::pageUp( bool sel )
 void KateViewInternal::pageDown( bool sel )
 {
   if (m_view->m_codeCompletion->codeCompletionVisible()) {
-    TQKeyEvent e(TQEvent::KeyPress, Qt::Key_PageDown, 0, 0);
+    TQKeyEvent e(TQEvent::KeyPress, TQt::Key_PageDown, 0, 0);
     m_view->m_codeCompletion->handleKey(&e);
     return;
   }
@@ -2025,7 +2025,7 @@ void KateViewInternal::bottom( bool sel )
 void KateViewInternal::top_home( bool sel )
 {
   if (m_view->m_codeCompletion->codeCompletionVisible()) {
-    TQKeyEvent e(TQEvent::KeyPress, Qt::Key_Home, 0, 0);
+    TQKeyEvent e(TQEvent::KeyPress, TQt::Key_Home, 0, 0);
     m_view->m_codeCompletion->handleKey(&e);
     return;
   }
@@ -2037,7 +2037,7 @@ void KateViewInternal::top_home( bool sel )
 void KateViewInternal::bottom_end( bool sel )
 {
   if (m_view->m_codeCompletion->codeCompletionVisible()) {
-    TQKeyEvent e(TQEvent::KeyPress, Qt::Key_End, 0, 0);
+    TQKeyEvent e(TQEvent::KeyPress, TQt::Key_End, 0, 0);
     m_view->m_codeCompletion->handleKey(&e);
     return;
   }
@@ -2438,7 +2438,7 @@ bool KateViewInternal::isTargetSelected( const TQPoint& p )
 
 bool KateViewInternal::eventFilter( TQObject *obj, TQEvent *e )
 {
-  if (TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(m_lineScroll))
+  if (obj == m_lineScroll)
   {
     // the second condition is to make sure a scroll on the vertical bar doesn't cause a horizontal scroll ;)
     if (e->type() == TQEvent::Wheel && m_lineScroll->minValue() != m_lineScroll->maxValue())
@@ -2465,7 +2465,7 @@ bool KateViewInternal::eventFilter( TQObject *obj, TQEvent *e )
           m_view->m_codeCompletion->abortCompletion();
       }
 
-      if ((k->key() == Qt::Key_Escape) && !m_view->config()->persistentSelection() )
+      if ((k->key() == TQt::Key_Escape) && !m_view->config()->persistentSelection() )
       {
         m_view->clearSelection();
         return true;
@@ -2525,7 +2525,7 @@ void KateViewInternal::keyPressEvent( TQKeyEvent* e )
     kdDebug (13030) << "hint around" << endl;
 
     if( e->key() == Key_Enter || e->key() == Key_Return  ||
-    (key == SHIFT + Qt::Key_Return) || (key == SHIFT + Qt::Key_Enter)) {
+    (key == SHIFT + TQt::Key_Return) || (key == SHIFT + TQt::Key_Enter)) {
       m_view->m_codeCompletion->doComplete();
       e->accept();
       return;
@@ -2538,14 +2538,14 @@ void KateViewInternal::keyPressEvent( TQKeyEvent* e )
     return;
   }
 
-  if ((key == Qt::Key_Return) || (key == Qt::Key_Enter))
+  if ((key == TQt::Key_Return) || (key == TQt::Key_Enter))
   {
     m_view->keyReturn();
     e->accept();
     return;
   }
 
-  if ((key == SHIFT + Qt::Key_Return) || (key == SHIFT + Qt::Key_Enter))
+  if ((key == SHIFT + TQt::Key_Return) || (key == SHIFT + TQt::Key_Enter))
   {
     uint ln = cursor.line();
     int col = cursor.col();
@@ -2573,7 +2573,7 @@ void KateViewInternal::keyPressEvent( TQKeyEvent* e )
     return;
   }
 
-  if (key == Qt::Key_Backspace || key == SHIFT + Qt::Key_Backspace)
+  if (key == TQt::Key_Backspace || key == SHIFT + TQt::Key_Backspace)
   {
     m_view->backspace();
     e->accept();
@@ -2584,7 +2584,7 @@ void KateViewInternal::keyPressEvent( TQKeyEvent* e )
     return;
   }
 
-  if  (key == Qt::Key_Tab || key == SHIFT+Qt::Key_Backtab || key == Qt::Key_Backtab)
+  if  (key == TQt::Key_Tab || key == SHIFT+TQt::Key_Backtab || key == TQt::Key_Backtab)
   {
     if (m_doc->invokeTabInterceptor(key)) {
       e->accept();
@@ -2592,7 +2592,7 @@ void KateViewInternal::keyPressEvent( TQKeyEvent* e )
     } else
     if (m_doc->configFlags() & KateDocumentConfig::cfTabIndents)
     {
-      if( key == Qt::Key_Tab )
+      if( key == TQt::Key_Tab )
       {
         if (m_view->hasSelection() || (m_doc->configFlags() & KateDocumentConfig::cfTabIndentsMode))
           m_doc->indent( m_view, cursor.line(), 1 );
@@ -2609,7 +2609,7 @@ void KateViewInternal::keyPressEvent( TQKeyEvent* e )
         return;
       }
 
-      if (key == SHIFT+Qt::Key_Backtab || key == Qt::Key_Backtab)
+      if (key == SHIFT+TQt::Key_Backtab || key == TQt::Key_Backtab)
       {
         m_doc->indent( m_view, cursor.line(), -1 );
         e->accept();
@@ -2693,7 +2693,7 @@ void KateViewInternal::mousePressEvent( TQMouseEvent* e )
 {
   switch (e->button())
   {
-    case Qt::LeftButton:
+    case TQt::LeftButton:
         m_selChangedByUser = false;
 
         if (possibleTripleClick)
@@ -2820,7 +2820,7 @@ void KateViewInternal::mouseDoubleClickEvent(TQMouseEvent *e)
 {
   switch (e->button())
   {
-    case Qt::LeftButton:
+    case TQt::LeftButton:
       m_selectionMode = Word;
 
       if ( e->state() & TQt::ShiftButton )
@@ -2902,7 +2902,7 @@ void KateViewInternal::mouseDoubleClickEvent(TQMouseEvent *e)
       }
 
       possibleTripleClick = true;
-      TQTimer::singleShot ( TQApplication::doubleClickInterval(), this, TQT_SLOT(tripleClickTimeout()) );
+      TQTimer::singleShot ( TQApplication::doubleClickInterval(), this, TQ_SLOT(tripleClickTimeout()) );
 
       scrollX = 0;
       scrollY = 0;
@@ -2927,7 +2927,7 @@ void KateViewInternal::mouseReleaseEvent( TQMouseEvent* e )
 {
   switch (e->button())
   {
-    case Qt::LeftButton:
+    case TQt::LeftButton:
       m_selectionMode = Default;
 //       selStartCached.setLine( -1 );
 
@@ -2956,7 +2956,7 @@ void KateViewInternal::mouseReleaseEvent( TQMouseEvent* e )
       e->accept ();
       break;
 
-    case Qt::MidButton:
+    case TQt::MidButton:
       placeCursor( e->pos() );
 
       if( m_doc->isReadWrite() )
@@ -2977,7 +2977,7 @@ void KateViewInternal::mouseReleaseEvent( TQMouseEvent* e )
 
 void KateViewInternal::mouseMoveEvent( TQMouseEvent* e )
 {
-  if( e->state() & Qt::LeftButton )
+  if( e->state() & TQt::LeftButton )
   {
     if (dragInfo.state == diPending)
     {
@@ -3276,7 +3276,7 @@ void KateViewInternal::wheelEvent(TQWheelEvent* e)
 	}
 	else
 	{
-		if (m_lineScroll->minValue() != m_lineScroll->maxValue() && e->orientation() != Qt::Horizontal)
+		if (m_lineScroll->minValue() != m_lineScroll->maxValue() && e->orientation() != TQt::Horizontal)
 		{
 			// React to this as a vertical event
 			if ( e->state() & ShiftButton )
