@@ -48,7 +48,7 @@
 #include <tdeio/global.h>
 #include <kservicetype.h>
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #include <X11/Xlib.h>
 #include <fixx11h.h>
 #endif
@@ -110,9 +110,9 @@ Kded::Kded(bool checkUpdates, bool new_startup)
   else
      cPath = tdesycoca_env;
   m_pTimer = new TQTimer(this);
-  connect(m_pTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(recreate()));
+  connect(m_pTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(recreate()));
 
-  TQTimer::singleShot(100, this, TQT_SLOT(installCrashHandler()));
+  TQTimer::singleShot(100, this, TQ_SLOT(installCrashHandler()));
 
   m_pDirWatch = 0;
 
@@ -316,7 +316,7 @@ KDEDModule *Kded::loadModule(const KService *s, bool onDemand)
         {
           m_modules.insert(obj, module);
           m_libs.insert(obj, lib);
-          connect(module, TQT_SIGNAL(moduleDeleted(KDEDModule *)), TQT_SLOT(slotKDEDModuleRemoved(KDEDModule *)));
+          connect(module, TQ_SIGNAL(moduleDeleted(KDEDModule *)), TQ_SLOT(slotKDEDModuleRemoved(KDEDModule *)));
           kdDebug(7020) << "Successfully loaded module '" << obj << "'\n";
           return module;
         }
@@ -400,12 +400,12 @@ void Kded::updateDirWatch()
   delete m_pDirWatch;
   m_pDirWatch = new KDirWatch;
 
-  TQObject::connect( m_pDirWatch, TQT_SIGNAL(dirty(const TQString&)),
-           this, TQT_SLOT(update(const TQString&)));
-  TQObject::connect( m_pDirWatch, TQT_SIGNAL(created(const TQString&)),
-           this, TQT_SLOT(update(const TQString&)));
-  TQObject::connect( m_pDirWatch, TQT_SIGNAL(deleted(const TQString&)),
-           this, TQT_SLOT(dirDeleted(const TQString&)));
+  TQObject::connect( m_pDirWatch, TQ_SIGNAL(dirty(const TQString&)),
+           this, TQ_SLOT(update(const TQString&)));
+  TQObject::connect( m_pDirWatch, TQ_SIGNAL(created(const TQString&)),
+           this, TQ_SLOT(update(const TQString&)));
+  TQObject::connect( m_pDirWatch, TQ_SIGNAL(deleted(const TQString&)),
+           this, TQ_SLOT(dirDeleted(const TQString&)));
 
   // For each resource
   for( TQStringList::ConstIterator it = m_allResourceDirs.begin();
@@ -480,7 +480,7 @@ void Kded::recreate(bool initial)
    if (!initial)
    {
       updateDirWatch(); // Update tree first, to be sure to miss nothing.
-      runBuildSycoca(this, TQT_SLOT(recreateDone()));
+      runBuildSycoca(this, TQ_SLOT(recreateDone()));
    }
    else
    {
@@ -491,7 +491,7 @@ void Kded::recreate(bool initial)
       if(delayedCheck)
       {
          // do a proper tdesycoca check after a delay
-         TQTimer::singleShot( 60000, this, TQT_SLOT( runDelayedCheck()));
+         TQTimer::singleShot( 60000, this, TQ_SLOT( runDelayedCheck()));
          m_needDelayedCheck = true;
          delayedCheck = false;
       }
@@ -667,9 +667,9 @@ KUpdateD::KUpdateD()
 {
     m_pDirWatch = new KDirWatch;
     m_pTimer = new TQTimer;
-    connect(m_pTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(runKonfUpdate()));
-    TQObject::connect( m_pDirWatch, TQT_SIGNAL(dirty(const TQString&)),
-           this, TQT_SLOT(slotNewUpdateFile()));
+    connect(m_pTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(runKonfUpdate()));
+    TQObject::connect( m_pDirWatch, TQ_SIGNAL(dirty(const TQString&)),
+           this, TQ_SLOT(slotNewUpdateFile()));
 
     TQStringList dirs = TDEGlobal::dirs()->findDirs("data", "tdeconf_update");
     for( TQStringList::ConstIterator it = dirs.begin();
@@ -704,7 +704,7 @@ void KUpdateD::slotNewUpdateFile()
 KHostnameD::KHostnameD(int pollInterval)
 {
     m_Timer.start(pollInterval, false /* repetitive */ );
-    connect(&m_Timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(checkHostname()));
+    connect(&m_Timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(checkHostname()));
     checkHostname();
 }
 
@@ -785,7 +785,7 @@ public:
           if( Kded::self()->newStartup())
              Kded::self()->initModules();
           else
-	     TQTimer::singleShot(500, Kded::self(), TQT_SLOT(initModules()));
+	     TQTimer::singleShot(500, Kded::self(), TQ_SLOT(initModules()));
        } else 
           runBuildSycoca();
 
@@ -955,8 +955,8 @@ extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
         (void) new KHostnameD(HostnamePollInterval); // Watch for hostname changes
 
      DCOPClient *client = kapp->dcopClient();
-     TQObject::connect(client, TQT_SIGNAL(applicationRemoved(const TQCString&)),
-             kded, TQT_SLOT(slotApplicationRemoved(const TQCString&)));
+     TQObject::connect(client, TQ_SIGNAL(applicationRemoved(const TQCString&)),
+             kded, TQ_SLOT(slotApplicationRemoved(const TQCString&)));
      client->setNotifications(true);
      client->setDaemonMode( true );
 
@@ -969,7 +969,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
      TQByteArray data;
      client->send( "*", "tdesycoca", "notifyDatabaseChanged()", data );
      client->send( "ksplash", "", "upAndRunning(TQString)",  TQString("kded"));
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
      XEvent e;
      e.xclient.type = ClientMessage;
      e.xclient.message_type = XInternAtom( tqt_xdisplay(), "_KDE_SPLASH_PROGRESS", False );
