@@ -63,7 +63,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <time.h>
-#include <memory> // auto_ptr
+#include <memory>
 
 typedef TQDict<KSycocaEntry> KBSEntryDict;
 typedef TQValueList<KSycocaEntry::List> KSycocaEntryListList;
@@ -376,8 +376,8 @@ bool KBuildSycoca::build()
      if (!m_trackId.isEmpty())
         g_vfolder->setTrackId(m_trackId);
 
-     connect(g_vfolder, TQT_SIGNAL(newService(const TQString &, KService **)),
-             this, TQT_SLOT(slotCreateEntry(const TQString &, KService **)));
+     connect(g_vfolder, TQ_SIGNAL(newService(const TQString &, KService **)),
+             this, TQ_SLOT(slotCreateEntry(const TQString &, KService **)));
              
      VFolderMenu::SubMenu *kdeMenu = g_vfolder->parseMenu("tde-applications.menu", true);
 
@@ -390,8 +390,8 @@ bool KBuildSycoca::build()
      (void) existingResourceDirs();
      *g_allResourceDirs += g_vfolder->allDirectories();
 
-     disconnect(g_vfolder, TQT_SIGNAL(newService(const TQString &, KService **)),
-             this, TQT_SLOT(slotCreateEntry(const TQString &, KService **)));
+     disconnect(g_vfolder, TQ_SIGNAL(newService(const TQString &, KService **)),
+             this, TQ_SLOT(slotCreateEntry(const TQString &, KService **)));
 
      if (g_changed || !g_allEntries)
      {
@@ -462,13 +462,13 @@ void KBuildSycoca::createMenu(TQString caption, TQString name, VFolderMenu::SubM
 bool KBuildSycoca::recreate()
 {
   TQString path(sycocaPath());
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
   printf("tdebuildsycoca: path='%s'\n", (const char*)path);
 #endif
 
   // KSaveFile first writes to a temp file.
   // Upon close() it moves the stuff to the right place.
-  std::auto_ptr<KSaveFile> database( new KSaveFile(path) );
+  std::unique_ptr<KSaveFile> database( new KSaveFile(path) );
   if (database->status() == EACCES && TQFile::exists(path))
   {
     TQFile::remove( path );
@@ -747,7 +747,7 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
 #ifdef KBUILDSYCOCA_GUI
    silent = args->isSet("silent");
    showprogress = args->isSet("showprogress");
-   TQLabel progress( TQString("<p><br><nobr>    %1    </nobr><br>").arg( i18n("Reloading TDE configuration, please wait...") ), 0, "", Qt::WType_Dialog | Qt::WStyle_DialogBorder  | Qt::WStyle_Customize| Qt::WStyle_Title );
+   TQLabel progress( TQString("<p><br><nobr>    %1    </nobr><br>").arg( i18n("Reloading TDE configuration, please wait...") ), 0, "", TQt::WType_Dialog | TQt::WStyle_DialogBorder  | TQt::WStyle_Customize| TQt::WStyle_Title );
    TQString capt = i18n("TDE Configuration Manager");
    if (!silent) {
      if (KMessageBox::No == KMessageBox::questionYesNo(0, i18n("Do you want to reload TDE configuration?"), capt, i18n("Reload"), i18n("Do Not Reload")))
@@ -790,8 +790,8 @@ extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
      while (dcopClient->isApplicationRegistered(appName))
      {
        WaitForSignal *obj = new WaitForSignal;
-       obj->connect(dcopClient, TQT_SIGNAL(applicationRemoved(const TQCString &)),
-               TQT_SLOT(deleteLater()));
+       obj->connect(dcopClient, TQ_SIGNAL(applicationRemoved(const TQCString &)),
+               TQ_SLOT(deleteLater()));
        kapp->eventLoop()->enterLoop();
      }
      dcopClient->setNotifications( false );
