@@ -80,7 +80,7 @@ const XCFImageFormat::LayerModes XCFImageFormat::layer_modes[] = {
 //! Change a TQRgb value's alpha only.
 inline TQRgb tqRgba ( TQRgb rgb, int a )
 {
-	return ((a & 0xff) << 24 | (rgb & TQRGB_MASK));
+	return ((a & 0xff) << 24 | (rgb & TQT_RGB_MASK));
 }
 
 
