@@ -334,7 +334,7 @@ KMountPoint::List KMountPoint::currentMountPoints(int infoNeeded)
     }
 
     free( mntctl_buffer );
-#elif defined(Q_WS_WIN)
+#elif defined(TQ_WS_WIN)
     //TODO?
 #else
    STRUCT_SETMNTENT mnttab;
