@@ -959,15 +959,15 @@ int TDEProcess::commSetupDoneP()
     innot =  new TQSocketNotifier(in[1], TQSocketNotifier::Write, this);
     TQ_CHECK_PTR(innot);
     innot->setEnabled(false); // will be enabled when data has to be sent
-    TQObject::connect(innot, TQT_SIGNAL(activated(int)),
-                     this, TQT_SLOT(slotSendData(int)));
+    TQObject::connect(innot, TQ_SIGNAL(activated(int)),
+                     this, TQ_SLOT(slotSendData(int)));
   }
 
   if (communication & Stdout) {
     outnot = new TQSocketNotifier(out[0], TQSocketNotifier::Read, this);
     TQ_CHECK_PTR(outnot);
-    TQObject::connect(outnot, TQT_SIGNAL(activated(int)),
-                     this, TQT_SLOT(slotChildOutput(int)));
+    TQObject::connect(outnot, TQ_SIGNAL(activated(int)),
+                     this, TQ_SLOT(slotChildOutput(int)));
     if (communication & NoRead)
         suspend();
   }
@@ -975,8 +975,8 @@ int TDEProcess::commSetupDoneP()
   if (communication & Stderr) {
     errnot = new TQSocketNotifier(err[0], TQSocketNotifier::Read, this );
     TQ_CHECK_PTR(errnot);
-    TQObject::connect(errnot, TQT_SIGNAL(activated(int)),
-                     this, TQT_SLOT(slotChildError(int)));
+    TQObject::connect(errnot, TQ_SIGNAL(activated(int)),
+                     this, TQ_SLOT(slotChildError(int)));
   }
 
   return 1;
