@@ -133,7 +133,7 @@ public:
    */
   static KURL stringToUrl(const TQCString &s);
 
-#ifdef Q_WS_QWS
+#ifdef TQ_WS_QWS
   /**
    * Convenience method that decodes the contents of @p e
    * into a list of KURLs for Qt versions without a MIME clipboard.
