@@ -33,7 +33,7 @@ class DCOPObject;
 #include <tqtglobaldefines.h>
 
 typedef unsigned long Atom;
-#if !defined(Q_WS_X11)
+#if !defined(TQ_WS_X11)
 typedef void Display;
 #endif
 
@@ -140,7 +140,7 @@ public:
 #endif // TDEAPPLICATION_BINARY_COMPAT_HACK
 #endif // Q_QDOC
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
   /**
    * Constructor. Parses command-line arguments. Use this constructor when you
    * you want ARGB support to be automatically detected and enabled.
@@ -187,7 +187,7 @@ public:
    * 
    * @see RGBADisplay()
    */
-  TDEApplication(Display *display, bool disable_argb, Qt::HANDLE visual, Qt::HANDLE colormap, bool allowStyles);
+  TDEApplication(Display *display, bool disable_argb, TQt::HANDLE visual, TQt::HANDLE colormap, bool allowStyles);
 
   /**
    * Constructor. Parses command-line arguments. Use this constructor when you
@@ -212,7 +212,7 @@ public:
    *
    * @since KDE 3.3
    */
-  TDEApplication(Display *display, Qt::HANDLE visual = 0, Qt::HANDLE colormap = 0,
+  TDEApplication(Display *display, TQt::HANDLE visual = 0, TQt::HANDLE colormap = 0,
                bool allowStyles=true);
 
   /**
@@ -621,7 +621,7 @@ public slots:
    * If the widget with focus provides a cut() slot, call that slot.  Thus for a
    * simple application cut can be implemented as:
    * \code
-   * KStdAction::cut( kapp, TQT_SLOT( cut() ), actionCollection() );
+   * KStdAction::cut( kapp, TQ_SLOT( cut() ), actionCollection() );
    * \endcode
    */
   void cut();
@@ -630,7 +630,7 @@ public slots:
    * If the widget with focus provides a copy() slot, call that slot.  Thus for a
    * simple application copy can be implemented as:
    * \code
-   * KStdAction::copy( kapp, TQT_SLOT( copy() ), actionCollection() );
+   * KStdAction::copy( kapp, TQ_SLOT( copy() ), actionCollection() );
    * \endcode
    */
   void copy();
@@ -639,7 +639,7 @@ public slots:
    * If the widget with focus provides a paste() slot, call that slot.  Thus for a
    * simple application copy can be implemented as:
    * \code
-   * KStdAction::paste( kapp, TQT_SLOT( paste() ), actionCollection() );
+   * KStdAction::paste( kapp, TQ_SLOT( paste() ), actionCollection() );
    * \endcode
    */
   void paste();
@@ -648,7 +648,7 @@ public slots:
    * If the widget with focus provides a clear() slot, call that slot.  Thus for a
    * simple application clear() can be implemented as:
    * \code
-   * new TDEAction( i18n( "Clear" ), "edit-clear", 0, kapp, TQT_SLOT( clear() ), actionCollection(), "clear" );
+   * new TDEAction( i18n( "Clear" ), "edit-clear", 0, kapp, TQ_SLOT( clear() ), actionCollection(), "clear" );
    * \endcode
    *
    * Note that for some widgets, this may not provide the intended bahavior.  For
@@ -675,7 +675,7 @@ public slots:
    * If the widget with focus provides a selectAll() slot, call that slot.  Thus for a
    * simple application select all can be implemented as:
    * \code
-   * KStdAction::selectAll( kapp, TQT_SLOT( selectAll() ), actionCollection() );
+   * KStdAction::selectAll( kapp, TQ_SLOT( selectAll() ), actionCollection() );
    * \endcode
    */
   void selectAll();
@@ -935,7 +935,7 @@ public:
    */
   TQString checkRecoverFile( const TQString& pFilename, bool& bRecover ) const;
 
-#if defined(Q_WS_X11)
+#if defined(TQ_WS_X11)
   /**
    * @internal
    * Get the X11 display
@@ -984,14 +984,14 @@ public:
    *
    * @return A pointer to the X11 display visual
    */
-   Qt::HANDLE getX11RGBAVisual(Display *dpy);
+   TQt::HANDLE getX11RGBAVisual(Display *dpy);
 
   /**
    * Returns the X11 display colormap
    *
    * @return An X11 display colormap object
    */
-   Qt::HANDLE getX11RGBAColormap(Display *dpy);
+   TQt::HANDLE getX11RGBAColormap(Display *dpy);
 
   /**
    * Returns whether or not X11 composition is available
@@ -1262,11 +1262,11 @@ protected:
    */
   TDEApplication( bool allowStyles, bool GUIenabled, TDEInstance* _instance );
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
   /**
    * @internal Used by KUniqueApplication
    */
-  TDEApplication( Display *display, Qt::HANDLE visual, Qt::HANDLE colormap,
+  TDEApplication( Display *display, TQt::HANDLE visual, TQt::HANDLE colormap,
 		  bool allowStyles, TDEInstance* _instance );
 
   /**
@@ -1287,7 +1287,7 @@ protected:
    * This method is used internally to determine which edit slots are implemented
    * by the widget that has the focus, and to invoke those slots if available.
    *
-   * @param slot is the slot as returned using the TQT_SLOT() macro, for example TQT_SLOT( cut() )
+   * @param slot is the slot as returned using the TQ_SLOT() macro, for example TQ_SLOT( cut() )
    *
    * This method can be used in TDEApplication subclasses to implement application wide
    * edit actions not supported by the TDEApplication class.  For example (in your subclass):
@@ -1295,7 +1295,7 @@ protected:
    * \code
    * void MyApplication::deselect()
    * {
-   *   invokeEditSlot( TQT_SLOT( deselect() ) );
+   *   invokeEditSlot( TQ_SLOT( deselect() ) );
    * }
    * \endcode
    *
@@ -1303,7 +1303,7 @@ protected:
    * focused widget if it provides this slot.  You can combine this with TDEAction with:
    *
    * \code
-   * KStdAction::deselect( static_cast<MyApplication *>( kapp ), TQT_SLOT( cut() ), actionCollection() );
+   * KStdAction::deselect( static_cast<MyApplication *>( kapp ), TQ_SLOT( cut() ), actionCollection() );
    * \endcode
    *
    * @see cut()
@@ -1352,9 +1352,9 @@ private:
   void initUrlActionRestrictions();
 
   bool argb_visual;
-#if defined(Q_WS_X11)
-  Qt::HANDLE argb_x11_visual;
-  Qt::HANDLE argb_x11_colormap;
+#if defined(TQ_WS_X11)
+  TQt::HANDLE argb_x11_visual;
+  TQt::HANDLE argb_x11_colormap;
 #endif
 
 public:
