@@ -43,13 +43,13 @@
 #include <kstringhandler.h>
 #include <kstaticdeleter.h>
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 #define DISPLAY "DISPLAY"
-#elif defined(Q_WS_QWS)
+#elif defined(TQ_WS_QWS)
 #define DISPLAY "QWS_DISPLAY"
 #endif
 
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 #include <win32_utils.h>
 #endif
 
@@ -184,7 +184,7 @@ TDECmdLineArgs::init(int _argc, char **_argv, const TDEAboutData *_about, bool n
    parsed = false;
    mCwd = mCwdd.setObject(mCwd, new char [PATH_MAX+1], true);
    (void) getcwd(mCwd, PATH_MAX);
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
    win32_slashify(mCwd, PATH_MAX);
 #endif
    if (!noKApp)
@@ -926,7 +926,7 @@ TDECmdLineArgs::usage(const char *id)
             name = name.mid(1);
             if ((name[0] == '[') && (name[name.length()-1] == ']'))
          name = name.mid(1, name.length()-2);
-            printQ(optionFormatString.arg(QString(name), -25)
+            printQ(optionFormatString.arg(TQString(name), -25)
      .arg(description));
          }
          else
@@ -950,12 +950,12 @@ TDECmdLineArgs::usage(const char *id)
                opt = opt + name;
                if (!option->def)
                {
-                  printQ(optionFormatString.arg(QString(opt), -25)
+                  printQ(optionFormatString.arg(TQString(opt), -25)
                          .arg(description));
                }
                else
                {
-                  printQ(optionFormatStringDef.arg(QString(opt), -25)
+                  printQ(optionFormatStringDef.arg(TQString(opt), -25)
                          .arg(description).arg(option->def));
                }
                opt = "";
@@ -1099,7 +1099,7 @@ TDECmdLineArgs::setOption(const TQCString &opt, const char *value)
       addArgument(arg);
       addArgument(value);
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
       // Hack coming up!
       if (arg == "-display")
       {
