@@ -53,7 +53,7 @@
 #include <kpixmapeffect.h>
 #include <kimageeffect.h>
 
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 # include <X11/Xlib.h>
 # ifdef HAVE_XRENDER
 #  include <X11/extensions/Xrender.h> // schroder
@@ -267,7 +267,7 @@ void TDEStyle::polish( const TQStyleControlElementData &ceData, ControlElementFl
 		TQWidget* widget = reinterpret_cast<TQWidget*>(ptr);
 		if ( d->useFilledFrameWorkaround )
 		{
-			if ( TQFrame *frame = ::tqqt_cast< TQFrame* >( widget ) ) {
+			if ( TQFrame *frame = ::tqt_cast< TQFrame* >( widget ) ) {
 				TQFrame::Shape shape = frame->frameShape();
 				if (shape == TQFrame::ToolBarPanel || shape == TQFrame::MenuBarPanel)
 					widget->installEventFilter(this);
@@ -291,7 +291,7 @@ void TDEStyle::unPolish( const TQStyleControlElementData &ceData, ControlElement
 		TQWidget* widget = reinterpret_cast<TQWidget*>(ptr);
 		if ( d->useFilledFrameWorkaround )
 		{
-			if ( TQFrame *frame = ::tqqt_cast< TQFrame* >( widget ) ) {
+			if ( TQFrame *frame = ::tqt_cast< TQFrame* >( widget ) ) {
 				TQFrame::Shape shape = frame->frameShape();
 				if (shape == TQFrame::ToolBarPanel || shape == TQFrame::MenuBarPanel)
 					widget->removeEventFilter(this);
@@ -537,7 +537,7 @@ void TDEStyle::drawTDEStylePrimitive( TDEStylePrimitive kpe,
 			break;
 
 		default:
-			p->fillRect(r, Qt::yellow);	// Something really bad happened - highlight.
+			p->fillRect(r, TQt::yellow);	// Something really bad happened - highlight.
 			break;
 	}
 }
@@ -664,7 +664,7 @@ void TDEStyle::drawPrimitive( PrimitiveElement pe,
 
 
 
-void TDEStyle::drawControl( TQ_ControlElement element,
+void TDEStyle::drawControl( ControlElement element,
 						  TQPainter* p,
 						  const TQStyleControlElementData &ceData,
 						  ControlElementFlags elementFlags,
@@ -853,7 +853,7 @@ void TDEStyle::drawControl( TQ_ControlElement element,
 		// ------------------------------------------------------------------------
 		case CE_ProgressBarGroove: {
 			TQRect fr = subRect(SR_ProgressBarGroove, ceData, elementFlags, widget);
-			drawPrimitive(PE_Panel, p, ceData, elementFlags, fr, cg, Style_Sunken, TQStyleOption::SO_Default);
+			drawPrimitive(PE_Panel, p, ceData, elementFlags, fr, cg, Style_Sunken, TQStyleOption::Default);
 			break;
 		}
 
@@ -1109,7 +1109,7 @@ static TQListViewItem* nextVisibleSibling(TQListViewItem* item)
     return sibling;
 }
 
-void TDEStyle::drawComplexControl( TQ_ComplexControl control,
+void TDEStyle::drawComplexControl( ComplexControl control,
 								 TQPainter* p,
 								 const TQStyleControlElementData &ceData,
 								 ControlElementFlags elementFlags,
@@ -1415,7 +1415,7 @@ void TDEStyle::drawComplexControl( TQ_ComplexControl control,
 }
 
 
-TQStyle::SubControl TDEStyle::querySubControl( TQ_ComplexControl control,
+TQStyle::SubControl TDEStyle::querySubControl( ComplexControl control,
 											const TQStyleControlElementData &ceData,
 											ControlElementFlags elementFlags,
 											const TQPoint &pos,
@@ -1433,7 +1433,7 @@ TQStyle::SubControl TDEStyle::querySubControl( TQ_ComplexControl control,
 }
 
 
-TQRect TDEStyle::querySubControlMetrics( TQ_ComplexControl control,
+TQRect TDEStyle::querySubControlMetrics( ComplexControl control,
 									  const TQStyleControlElementData &ceData,
 									  ControlElementFlags elementFlags,
 									  SubControl sc,
@@ -1927,17 +1927,17 @@ bool TDEStyle::objectEventHandler( const TQStyleControlElementData &ceData, Cont
 			// -- Karol.
 			TQFrame *frame = 0;
 			if ( event->type() == TQEvent::Paint
-					&& (frame = ::tqqt_cast<TQFrame*>(object)) )
+					&& (frame = ::tqt_cast<TQFrame*>(object)) )
 			{
 				if (frame->frameShape() != TQFrame::ToolBarPanel && frame->frameShape() != TQFrame::MenuBarPanel)
 					return false;
 
 				bool horizontal = true;
 				TQPaintEvent* pe = (TQPaintEvent*)event;
-				TQToolBar *toolbar = ::tqqt_cast< TQToolBar *>( frame );
+				TQToolBar *toolbar = ::tqt_cast< TQToolBar *>( frame );
 				TQRect r = pe->rect();
 
-				if (toolbar && toolbar->orientation() == Qt::Vertical)
+				if (toolbar && toolbar->orientation() == TQt::Vertical)
 					horizontal = false;
 
 				if (horizontal) {
@@ -2141,7 +2141,7 @@ TQImage TransparencyHandler::handleRealAlpha(TQImage img) {
 // Create a shadow of thickness 4.
 void TransparencyHandler::createShadowWindows(const TQWidget* p)
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 	int x2 = p->x()+p->width();
 	int y2 = p->y()+p->height();
 	TQRect shadow1(x2, p->y() + 4, 4, p->height());
@@ -2200,7 +2200,7 @@ void TransparencyHandler::createShadowWindows(const TQWidget* p)
 
 void TransparencyHandler::removeShadowWindows(const TQWidget* p)
 {
-#ifdef Q_WS_X11
+#ifdef TQ_WS_X11
 	ShadowMap::iterator it = shadowMap().find(p);
 	if (it != shadowMap().end())
 	{
@@ -2219,7 +2219,7 @@ void TransparencyHandler::removeShadowWindows(const TQWidget* p)
 
 bool TransparencyHandler::eventFilter( TQObject* object, TQEvent* event )
 {
-#if !defined Q_WS_MAC && !defined Q_WS_WIN
+#if !defined TQ_WS_MAC && !defined TQ_WS_WIN
 	// Transparency idea was borrowed from KDE2's "MegaGradient" Style,
 	// Copyright (C) 2000 Daniel M. Duley <mosfet@kde.org>
 
@@ -2317,8 +2317,8 @@ void TransparencyHandler::blendToPixmap(const TQColorGroup &cg, const TQWidget*
 		return;
 
 	// Allow styles to define the blend pixmap - allows for some interesting effects.
-	if (::tqqt_cast<TQPopupMenu*>(p))
-		tdestyle->renderMenuBlendPixmap( blendPix, cg, ::tqqt_cast<TQPopupMenu*>(p) );
+	if (::tqt_cast<TQPopupMenu*>(p))
+		tdestyle->renderMenuBlendPixmap( blendPix, cg, ::tqt_cast<TQPopupMenu*>(p) );
 	else
 		blendPix.fill(cg.button());	// Just tint as the default behavior
 
@@ -2339,9 +2339,9 @@ void TransparencyHandler::XRenderBlendToPixmap(const TQWidget* p)
 	renderPix.resize( pix.width(), pix.height() );
 
 	// Allow styles to define the blend pixmap - allows for some interesting effects.
-	if (::tqqt_cast<TQPopupMenu*>(p))
+	if (::tqt_cast<TQPopupMenu*>(p))
 	   tdestyle->renderMenuBlendPixmap( renderPix, p->colorGroup(),
-			   ::tqqt_cast<TQPopupMenu*>(p) );
+			   ::tqt_cast<TQPopupMenu*>(p) );
 	else
 		renderPix.fill(p->colorGroup().button());	// Just tint as the default behavior
 
