@@ -347,10 +347,10 @@ KJavaAppletViewer::KJavaAppletViewer (TQWidget * wparent, const char *,
     setInstance (KJavaAppletViewerFactory::instance ());
     KParts::Part::setWidget (m_view);
 
-    connect (applet->getContext(), TQT_SIGNAL(appletLoaded()), this, TQT_SLOT(appletLoaded()));
-    connect (applet->getContext(), TQT_SIGNAL(showDocument(const TQString&, const TQString&)), m_browserextension, TQT_SLOT(showDocument(const TQString&, const TQString&)));
-    connect (applet->getContext(), TQT_SIGNAL(showStatus(const TQString &)), this, TQT_SLOT(infoMessage(const TQString &)));
-    connect (applet, TQT_SIGNAL(jsEvent (const TQStringList &)), m_liveconnect, TQT_SLOT(jsEvent (const TQStringList &)));
+    connect (applet->getContext(), TQ_SIGNAL(appletLoaded()), this, TQ_SLOT(appletLoaded()));
+    connect (applet->getContext(), TQ_SIGNAL(showDocument(const TQString&, const TQString&)), m_browserextension, TQ_SLOT(showDocument(const TQString&, const TQString&)));
+    connect (applet->getContext(), TQ_SIGNAL(showStatus(const TQString &)), this, TQ_SLOT(infoMessage(const TQString &)));
+    connect (applet, TQ_SIGNAL(jsEvent (const TQStringList &)), m_liveconnect, TQ_SLOT(jsEvent (const TQStringList &)));
 }
 
 bool KJavaAppletViewer::eventFilter (TQObject *o, TQEvent *e) {
@@ -369,7 +369,7 @@ bool KJavaAppletViewer::eventFilter (TQObject *o, TQEvent *e) {
 
 KJavaAppletViewer::~KJavaAppletViewer () {
     m_view = 0L;
-    serverMaintainer->releaseContext (TQT_TQOBJECT(parent()), baseurl);
+    serverMaintainer->releaseContext (parent(), baseurl);
     if (m_statusbar_icon) {
         m_statusbar->removeStatusBarItem (m_statusbar_icon);
         delete m_statusbar_icon;
@@ -404,7 +404,7 @@ bool KJavaAppletViewer::openURL (const KURL & url) {
     if (applet->size().width() > 0 || m_view->isVisible())
         w->showApplet ();
     else
-        TQTimer::singleShot (10, this, TQT_SLOT (delayedCreateTimeOut ()));
+        TQTimer::singleShot (10, this, TQ_SLOT (delayedCreateTimeOut ()));
     if (!applet->failed ())
         emit started (0L);
     return url.isValid ();
