@@ -1450,7 +1450,7 @@ public:
     static short initialBorderHorizontalSpacing() { return 0; }
     static short initialBorderVerticalSpacing() { return 0; }
     static ECursor initialCursor() { return CURSOR_AUTO; }
-    static TQColor initialColor() { return Qt::black; }
+    static TQColor initialColor() { return TQt::black; }
     static CachedImage* initialBackgroundImage() { return 0; }
     static CachedImage* initialListStyleImage() { return 0; }
     static unsigned short initialBorderWidth() { return 3; }
