@@ -508,13 +508,13 @@ void NodeImpl::dispatchMouseEvent(TQMouseEvent *_mouse, int overrideId, int over
 
     int button = -1;
     switch (_mouse->button()) {
-        case Qt::LeftButton:
+        case TQt::LeftButton:
             button = 0;
             break;
-        case Qt::MidButton:
+        case TQt::MidButton:
             button = 1;
             break;
-        case Qt::RightButton:
+        case TQt::RightButton:
             button = 2;
             break;
         default:
@@ -1659,7 +1659,7 @@ NodeImpl *NodeListImpl::item( unsigned long index ) const
     bool      usedCache = false;
     if (m_cache->current.node) {
         //Compute distance from the requested index to the cache node
-        long cacheDist = QABS(long(index) - long(m_cache->position));
+        long cacheDist = TQABS(long(index) - long(m_cache->position));
 
         if (cacheDist < (long)index) { //Closer to the cached position
             usedCache = true;
