@@ -27,7 +27,7 @@ class KOpenSSLProxyPrivate;
 
 #include <klibloader.h>
 
-#ifdef Q_WS_WIN
+#ifdef TQ_WS_WIN
 #include "ksslconfig_win.h"
 #else
 #include "ksslconfig.h"
