@@ -447,11 +447,11 @@ namespace KPAC
 	  throw Error( "No such function FindProxyForURL" );
 
         KURL cleanUrl = url;
-        cleanUrl.setPass(QString());
-        cleanUrl.setUser(QString());
+        cleanUrl.setPass(TQString());
+        cleanUrl.setUser(TQString());
         if (cleanUrl.protocol().lower() == "https") {
-            cleanUrl.setPath(QString());
-            cleanUrl.setQuery(QString());
+            cleanUrl.setPath(TQString());
+            cleanUrl.setQuery(TQString());
         }
 
 	Object thisObj;
@@ -469,5 +469,3 @@ namespace KPAC
         return retval.toString( exec ).qstring();
     }
 }
-
-// vim: ts=4 sw=4 et
