@@ -93,9 +93,9 @@ TDEIconCanvas::TDEIconCanvas(TQWidget *parent, const char *name)
 {
     d = new TDEIconCanvasPrivate;
     mpTimer = new TQTimer(this);
-    connect(mpTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotLoadFiles()));
-    connect(this, TQT_SIGNAL(currentChanged(TQIconViewItem *)),
-	    TQT_SLOT(slotCurrentChanged(TQIconViewItem *)));
+    connect(mpTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotLoadFiles()));
+    connect(this, TQ_SIGNAL(currentChanged(TQIconViewItem *)),
+	    TQ_SLOT(slotCurrentChanged(TQIconViewItem *)));
     setGridX(80);
     setWordWrapIconText(false);
     setShowToolTips(true);
@@ -119,7 +119,7 @@ void TDEIconCanvas::loadFiles(const TQStringList& files)
 void TDEIconCanvas::slotLoadFiles()
 {
     setResizeMode(Fixed);
-    TQApplication::setOverrideCursor(tqwaitCursor);
+    TQApplication::setOverrideCursor(TQt::waitCursor);
 
     // disable updates to not trigger paint events when adding child items
     setUpdatesEnabled( false );
@@ -267,16 +267,16 @@ void TDEIconDialog::init()
     TQVBoxLayout *top = new TQVBoxLayout(main);
     top->setSpacing( spacingHint() );
 
-    TQButtonGroup *bgroup = new TQButtonGroup(0, Qt::Vertical, i18n("Icon Source"), main);
+    TQButtonGroup *bgroup = new TQButtonGroup(0, TQt::Vertical, i18n("Icon Source"), main);
     bgroup->layout()->setSpacing(KDialog::spacingHint());
     bgroup->layout()->setMargin(KDialog::marginHint());
     top->addWidget(bgroup);
-    connect(bgroup, TQT_SIGNAL(clicked(int)), TQT_SLOT(slotButtonClicked(int)));
+    connect(bgroup, TQ_SIGNAL(clicked(int)), TQ_SLOT(slotButtonClicked(int)));
     TQGridLayout *grid = new TQGridLayout(bgroup->layout(), 3, 2);
     mpRb1 = new TQRadioButton(i18n("S&ystem icons:"), bgroup);
     grid->addWidget(mpRb1, 1, 0);
     mpCombo = new TQComboBox(bgroup);
-    connect(mpCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotContext(int)));
+    connect(mpCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotContext(int)));
     grid->addWidget(mpCombo, 1, 1);
     mpRb2 = new TQRadioButton(i18n("O&ther icons:"), bgroup);
     grid->addWidget(mpRb2, 2, 0);
@@ -303,7 +303,7 @@ void TDEIconDialog::init()
 
 
     // signals and slots connections
-    connect(clearSearch, TQT_SIGNAL(clicked()), d->searchLine, TQT_SLOT(clear()));
+    connect(clearSearch, TQ_SIGNAL(clicked()), d->searchLine, TQ_SLOT(clear()));
 
     TQString wtstr = i18n("Search interactively for icon names (e.g. folder).");
     TQWhatsThis::add(searchLabel, wtstr);
@@ -311,20 +311,20 @@ void TDEIconDialog::init()
 
 
     mpCanvas = new TDEIconCanvas(main);
-    connect(mpCanvas, TQT_SIGNAL(executed(TQIconViewItem *)), TQT_SLOT(slotAcceptIcons()));
-    connect(mpCanvas, TQT_SIGNAL(returnPressed(TQIconViewItem *)), TQT_SLOT(slotAcceptIcons()));
+    connect(mpCanvas, TQ_SIGNAL(executed(TQIconViewItem *)), TQ_SLOT(slotAcceptIcons()));
+    connect(mpCanvas, TQ_SIGNAL(returnPressed(TQIconViewItem *)), TQ_SLOT(slotAcceptIcons()));
     mpCanvas->setMinimumSize(400, 125);
     top->addWidget(mpCanvas);
     d->searchLine->setIconView(mpCanvas);
 
     mpProgress = new KProgress(main);
     top->addWidget(mpProgress);
-    connect(mpCanvas, TQT_SIGNAL(startLoading(int)), TQT_SLOT(slotStartLoading(int)));
-    connect(mpCanvas, TQT_SIGNAL(progress(int)), TQT_SLOT(slotProgress(int)));
-    connect(mpCanvas, TQT_SIGNAL(finished()), TQT_SLOT(slotFinished()));
+    connect(mpCanvas, TQ_SIGNAL(startLoading(int)), TQ_SLOT(slotStartLoading(int)));
+    connect(mpCanvas, TQ_SIGNAL(progress(int)), TQ_SLOT(slotProgress(int)));
+    connect(mpCanvas, TQ_SIGNAL(finished()), TQ_SLOT(slotFinished()));
 
     // When pressing Ok or Cancel, stop loading icons
-    connect(this, TQT_SIGNAL(hidden()), mpCanvas, TQT_SLOT(stopLoading()));
+    connect(this, TQ_SIGNAL(hidden()), mpCanvas, TQ_SLOT(stopLoading()));
 
     static const char* const context_text[] = {
         I18N_NOOP( "Actions" ),
@@ -679,7 +679,7 @@ void TDEIconButton::init( TDEIconLoader *loader )
 
     mpLoader = loader;
     mpDialog = 0L;
-    connect(this, TQT_SIGNAL(clicked()), TQT_SLOT(slotChangeIcon()));
+    connect(this, TQ_SIGNAL(clicked()), TQ_SLOT(slotChangeIcon()));
 }
 
 TDEIconButton::~TDEIconButton()
@@ -723,7 +723,7 @@ void TDEIconButton::setIcon(const TQString& icon)
     if (!mpDialog)
     {
         mpDialog = new TDEIconDialog(mpLoader, this);
-        connect(mpDialog, TQT_SIGNAL(newIconName(const TQString&)), TQT_SLOT(newIconName(const TQString&)));
+        connect(mpDialog, TQ_SIGNAL(newIconName(const TQString&)), TQ_SLOT(newIconName(const TQString&)));
     }
 
     if ( mbUser )
@@ -741,7 +741,7 @@ void TDEIconButton::slotChangeIcon()
     if (!mpDialog)
     {
         mpDialog = new TDEIconDialog(mpLoader, this);
-        connect(mpDialog, TQT_SIGNAL(newIconName(const TQString&)), TQT_SLOT(newIconName(const TQString&)));
+        connect(mpDialog, TQ_SIGNAL(newIconName(const TQString&)), TQ_SLOT(newIconName(const TQString&)));
     }
 
     mpDialog->setup( mGroup, mContext, d->m_bStrictIconSize, d->iconSize, mbUser );
