@@ -12,7 +12,7 @@
 
 class KFDTest : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 
 public:
     KFDTest( const TQString& startDir, TQObject *parent = 0, const char *name = 0);
