@@ -50,8 +50,8 @@ namespace TDEIO {
      *
      * \code
      *   TDEIO::Job * job = TDEIO::someoperation( some parameters );
-     *   connect( job, TQT_SIGNAL( result( TDEIO::Job * ) ),
-     *            this, TQT_SLOT( slotResult( TDEIO::Job * ) ) );
+     *   connect( job, TQ_SIGNAL( result( TDEIO::Job * ) ),
+     *            this, TQ_SLOT( slotResult( TDEIO::Job * ) ) );
      * \endcode
      *   (other connects, specific to the job)
      *
@@ -65,7 +65,7 @@ namespace TDEIO {
      * @see TDEIO::Slave
      */
     class TDEIO_EXPORT Job : public TQObject {
-        Q_OBJECT
+        TQ_OBJECT
 
     protected:
         Job( bool showProgressInfo );
@@ -525,7 +525,7 @@ namespace TDEIO {
      * that manage subjobs but aren't scheduled directly.
      */
     class TDEIO_EXPORT SimpleJob : public TDEIO::Job {
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
         /**
@@ -686,7 +686,7 @@ namespace TDEIO {
      */
     class TDEIO_EXPORT StatJob : public SimpleJob {
 
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
         /**
@@ -778,7 +778,7 @@ namespace TDEIO {
      */
     class TDEIO_EXPORT MkdirJob : public SimpleJob {
 
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
         /**
@@ -836,7 +836,7 @@ namespace TDEIO {
      * Used for direct copy from or to the local filesystem (i.e. SlaveBase::copy())
      */
     class TDEIO_EXPORT DirectCopyJob : public SimpleJob {
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
         /**
@@ -872,7 +872,7 @@ namespace TDEIO {
      * reading of data from the slave should be suspended.
      */
     class TDEIO_EXPORT TransferJob : public SimpleJob {
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
        /**
@@ -1072,7 +1072,7 @@ namespace TDEIO {
      * @since 3.3
      */
     class TDEIO_EXPORT StoredTransferJob : public TDEIO::TransferJob {
-        Q_OBJECT
+        TQ_OBJECT
 
     public:
        /**
@@ -1117,7 +1117,7 @@ namespace TDEIO {
      * @see TDEIO::multi_get()
      */
     class TDEIO_EXPORT MultiGetJob : public TransferJob {
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
         /**
@@ -1205,7 +1205,7 @@ namespace TDEIO {
      * @see TDEIO::mimetype()
      */
     class TDEIO_EXPORT MimetypeJob : public TransferJob {
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
        /**
@@ -1247,7 +1247,7 @@ namespace TDEIO {
      * @see TDEIO::file_move()
      */
     class TDEIO_EXPORT FileCopyJob : public Job {
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
 	/**
@@ -1389,7 +1389,7 @@ namespace TDEIO {
      * @see TDEIO::listDir()
      */
     class TDEIO_EXPORT ListJob : public SimpleJob {
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
        /**
@@ -1505,7 +1505,7 @@ namespace TDEIO {
      * @see TDEIO::linkAs()
      */
     class TDEIO_EXPORT CopyJob : public Job {
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
 	/**
@@ -1760,7 +1760,7 @@ namespace TDEIO {
      * @see TDEIO::del()
      */
     class TDEIO_EXPORT DeleteJob : public Job {
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
 	/**
@@ -1864,7 +1864,7 @@ namespace TDEIO {
      */
     class TDEIO_EXPORT LocalURLJob : public SimpleJob {
 
-    Q_OBJECT
+    TQ_OBJECT
 
     public:
         /**
