@@ -95,8 +95,8 @@ public:
 
 #ifdef qdoc
 #else
-    virtual TQT_TQIO_LONG tqreadBlock( char *data, TQT_TQIO_ULONG maxlen );
-    virtual TQT_TQIO_LONG tqwriteBlock( const char *data, TQT_TQIO_ULONG len );
+    virtual TQ_LONG readBlock( char *data, TQ_ULONG maxlen );
+    virtual TQ_LONG writeBlock( const char *data, TQ_ULONG len );
 #endif
     //int readLine( char *data, uint maxlen );
 
