@@ -58,7 +58,7 @@ namespace TDEIO {
    */
 class TDEIO_EXPORT NetAccess : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
 
 public:
     /**
