@@ -10,7 +10,7 @@ namespace TDEIO { class Job; }
 
 class KIOExec : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     KIOExec();
 
