@@ -569,7 +569,7 @@ void FileProtocol::put( const KURL& url, int _mode, bool _overwrite, bool _resum
     // set modification time
     const TQString mtimeStr = metaData( "modified" );
     if ( !mtimeStr.isEmpty() ) {
-        TQDateTime dt = TQT_TQDATETIME_OBJECT(TQDateTime::fromString( mtimeStr, Qt::ISODate ));
+        TQDateTime dt = TQDateTime::fromString( mtimeStr, TQt::ISODate );
         if ( dt.isValid() ) {
             KDE_struct_stat dest_statbuf;
             if (KDE_stat( _dest_orig.data(), &dest_statbuf ) == 0) {
@@ -1336,10 +1336,10 @@ void FileProtocol::special( const TQByteArray &data)
       TQString filename;
       stream >> filename;
       KShred shred( filename );
-      connect( &shred, TQT_SIGNAL( processedSize( TDEIO::filesize_t ) ),
-               this, TQT_SLOT( slotProcessedSize( TDEIO::filesize_t ) ) );
-      connect( &shred, TQT_SIGNAL( infoMessage( const TQString & ) ),
-               this, TQT_SLOT( slotInfoMessage( const TQString & ) ) );
+      connect( &shred, TQ_SIGNAL( processedSize( TDEIO::filesize_t ) ),
+               this, TQ_SLOT( slotProcessedSize( TDEIO::filesize_t ) ) );
+      connect( &shred, TQ_SIGNAL( infoMessage( const TQString & ) ),
+               this, TQ_SLOT( slotInfoMessage( const TQString & ) ) );
       if (!shred.shred())
           error( TDEIO::ERR_CANNOT_DELETE, filename );
       else
@@ -1446,15 +1446,15 @@ void FileProtocol::mount( bool _ro, const char *_fstype, const TQString& _dev, c
               buffer.sprintf( "%s %s %s %s 2>%s", mountProg.latin1(), readonly.data(), dev.data(), point.data(), tmp );
             else
               // mount giving device + mountpoint + fstype
-#if defined(__svr4__) && defined(__sun__)
-							  // MACRO for Solaris 8 and I
+#if defined(Q_OS_SOLARIS)
+		// MACRO for Solaris 8 and I
                 // believe this is true for SVR4 in general
-                buffer.sprintf( "%s -F %s %s %s %s 2>%s"
-				mountProg.latin1()
-                                fstype.data()
-                                _ro ? "-oro" : ""
-                                dev.data()
-                                point.data()
+                buffer.sprintf( "%s -F %s %s %s %s 2>%s",
+				mountProg.latin1(),
+                                fstype.data(),
+                                _ro ? "-oro" : "",
+                                dev.data(),
+                                point.data(),
                                 tmp );
 #elif defined(__OpenBSD__)
               buffer.sprintf( "%s %s %s -t %s %s %s 2>%s", "tdesu", mountProg.latin1(), readonly.data(),
