@@ -57,8 +57,8 @@ GUIClient::GUIClient (KMDI::MainWindow* mdiMainFrm,const char* name)
 {
   m_mdiMainFrm=mdiMainFrm;
 
-  connect( mdiMainFrm->guiFactory(), TQT_SIGNAL( clientAdded( KXMLGUIClient * ) ),
-           this, TQT_SLOT( clientAdded( KXMLGUIClient * ) ) );
+  connect( mdiMainFrm->guiFactory(), TQ_SIGNAL( clientAdded( KXMLGUIClient * ) ),
+           this, TQ_SLOT( clientAdded( KXMLGUIClient * ) ) );
 
   /* re-use an existing resource file if it exists. can happen if the user launches the
    * toolbar editor */
@@ -79,18 +79,18 @@ GUIClient::GUIClient (KMDI::MainWindow* mdiMainFrm,const char* name)
   m_toolMenu=new TDEActionMenu(i18n("Tool &Views"),actionCollection(),"tdemdi_toolview_menu");
 
   m_gotoToolDockMenu=new TDEActionMenu(i18n("Tool &Docks"),actionCollection(),"tdemdi_tooldock_menu");
-  m_gotoToolDockMenu->insert(new TDEAction(i18n("Switch Top Dock"),ALT+CTRL+SHIFT+Key_T,this,TQT_SIGNAL(toggleTop()),
+  m_gotoToolDockMenu->insert(new TDEAction(i18n("Switch Top Dock"),ALT+CTRL+SHIFT+Key_T,this,TQ_SIGNAL(toggleTop()),
   actionCollection(),"tdemdi_activate_top"));
-  m_gotoToolDockMenu->insert(new TDEAction(i18n("Switch Left Dock"),ALT+CTRL+SHIFT+Key_L,this,TQT_SIGNAL(toggleLeft()),
+  m_gotoToolDockMenu->insert(new TDEAction(i18n("Switch Left Dock"),ALT+CTRL+SHIFT+Key_L,this,TQ_SIGNAL(toggleLeft()),
   actionCollection(),"tdemdi_activate_left"));
-  m_gotoToolDockMenu->insert(new TDEAction(i18n("Switch Right Dock"),ALT+CTRL+SHIFT+Key_R,this,TQT_SIGNAL(toggleRight()),
+  m_gotoToolDockMenu->insert(new TDEAction(i18n("Switch Right Dock"),ALT+CTRL+SHIFT+Key_R,this,TQ_SIGNAL(toggleRight()),
   actionCollection(),"tdemdi_activate_right"));
-  m_gotoToolDockMenu->insert(new TDEAction(i18n("Switch Bottom Dock"),ALT+CTRL+SHIFT+Key_B,this,TQT_SIGNAL(toggleBottom()),
+  m_gotoToolDockMenu->insert(new TDEAction(i18n("Switch Bottom Dock"),ALT+CTRL+SHIFT+Key_B,this,TQ_SIGNAL(toggleBottom()),
   actionCollection(),"tdemdi_activate_bottom"));
   m_gotoToolDockMenu->insert(new TDEActionSeparator(actionCollection(),"tdemdi_goto_menu_separator"));
-  m_gotoToolDockMenu->insert(new TDEAction(i18n("Previous Tool View"),ALT+CTRL+Key_Left,TQT_TQOBJECT(m_mdiMainFrm),TQT_SLOT(prevToolViewInDock()),
+  m_gotoToolDockMenu->insert(new TDEAction(i18n("Previous Tool View"),ALT+CTRL+Key_Left,m_mdiMainFrm,TQ_SLOT(prevToolViewInDock()),
   actionCollection(),"tdemdi_prev_toolview"));
-  m_gotoToolDockMenu->insert(new TDEAction(i18n("Next Tool View"),ALT+CTRL+Key_Right,TQT_TQOBJECT(m_mdiMainFrm),TQT_SLOT(nextToolViewInDock()),
+  m_gotoToolDockMenu->insert(new TDEAction(i18n("Next Tool View"),ALT+CTRL+Key_Right,m_mdiMainFrm,TQ_SLOT(nextToolViewInDock()),
   actionCollection(),"tdemdi_next_toolview"));
 
   actionCollection()->readShortcutSettings( "Shortcuts", kapp->config() );
@@ -146,12 +146,12 @@ void GUIClient::addToolView(KMDI::ToolViewAccessor* mtva)
   cfg->setGroup( _grp );
 
   TDEAction *a=new ToggleToolViewAction(i18n("Show %1").arg(mtva->wrappedWidget()->caption()),
-    /*TQString::null*/sc,tqt_dynamic_cast<KDockWidget*>(mtva->wrapperWidget()),
+    /*TQString::null*/sc,dynamic_cast<KDockWidget*>(mtva->wrapperWidget()),
     m_mdiMainFrm,actionCollection(), aname.latin1() );
 
   ((ToggleToolViewAction*)a)->setCheckedState(TQString(i18n("Hide %1").arg(mtva->wrappedWidget()->caption())));
 
-  connect(a,TQT_SIGNAL(destroyed(TQObject*)),this,TQT_SLOT(actionDeleted(TQObject*)));
+  connect(a,TQ_SIGNAL(destroyed(TQObject*)),this,TQ_SLOT(actionDeleted(TQObject*)));
 
   m_toolViewActions.append(a);
   m_toolMenu->insert(a);
@@ -181,9 +181,9 @@ ToggleToolViewAction::ToggleToolViewAction ( const TQString& text, const TDEShor
 {
   if (m_dw)
   {
-    connect(this,TQT_SIGNAL(toggled(bool)),this,TQT_SLOT(slotToggled(bool)));
-    connect(m_dw->dockManager(),TQT_SIGNAL(change()),this,TQT_SLOT(anDWChanged()));
-    connect(m_dw,TQT_SIGNAL(destroyed()),this,TQT_SLOT(slotWidgetDestroyed()));
+    connect(this,TQ_SIGNAL(toggled(bool)),this,TQ_SLOT(slotToggled(bool)));
+    connect(m_dw->dockManager(),TQ_SIGNAL(change()),this,TQ_SLOT(anDWChanged()));
+    connect(m_dw,TQ_SIGNAL(destroyed()),this,TQ_SLOT(slotWidgetDestroyed()));
 
     setChecked(m_dw->mayBeHide());
   }
@@ -201,7 +201,7 @@ void ToggleToolViewAction::anDWChanged()
   else if ((!isChecked()) && m_dw->mayBeHide())
     setChecked(true);
   else if (isChecked() && (m_dw->parentDockTabGroup() &&
-          ((::tqqt_cast<KDockWidget*>(m_dw->parentDockTabGroup()->
+          ((::tqt_cast<KDockWidget*>(m_dw->parentDockTabGroup()->
                   parent()))->mayBeShow())))
     setChecked(false);
 }
@@ -218,8 +218,8 @@ void ToggleToolViewAction::slotToggled(bool t)
 
 void ToggleToolViewAction::slotWidgetDestroyed()
 {
-  disconnect(m_dw->dockManager(),TQT_SIGNAL(change()),this,TQT_SLOT(anDWChanged()));
-  disconnect(this,TQT_SIGNAL(toggled(bool)),0,0);
+  disconnect(m_dw->dockManager(),TQ_SIGNAL(change()),this,TQ_SLOT(anDWChanged()));
+  disconnect(this,TQ_SIGNAL(toggled(bool)),0,0);
 
   unplugAll();
   deleteLater();
