@@ -240,7 +240,7 @@ class KMDI_EXPORT KMdiMainFrm : public KParts::DockMainWindow
 {
 	friend class KMdiChildView;
 	friend class KMdiTaskBar;
-	Q_OBJECT
+	TQ_OBJECT
 
 	friend class KMdiToolViewAccessor;
 	// attributes
