@@ -479,7 +479,7 @@ KDE_EXPORT int KRsync::establishConnectionRsync(char *buffer, TDEIO::fileoffset_
                     m_progressDialog->setAutoClose(true);
                     m_progressDialog->progressBar()->setTotalSteps(2);
                     m_progressDialog->progressBar()->setValue(1);
-                    connect (m_progressDialog, TQT_SIGNAL(cancelClicked()), TQT_SLOT(slotRsyncCancelled()));
+                    connect (m_progressDialog, TQ_SIGNAL(cancelClicked()), TQ_SLOT(slotRsyncCancelled()));
                     if (m_bInSpecialSync) m_progressDialog->move(0,0);
                     m_progressDialog->show();
                     m_progressDialogExists = true;
@@ -602,7 +602,7 @@ KDE_EXPORT int KRsync::establishConnectionUnison(char *buffer, TDEIO::fileoffset
                     m_progressDialog->progressBar()->setFormat("%v / %m");
                     m_progressDialog->progressBar()->setTotalSteps(0);
                     m_progressDialog->setAutoClose(true);
-                    connect (m_progressDialog, TQT_SIGNAL(cancelClicked()), TQT_SLOT(slotUnisonCancelled()));
+                    connect (m_progressDialog, TQ_SIGNAL(cancelClicked()), TQ_SLOT(slotUnisonCancelled()));
                     if (m_bInSpecialSync) m_progressDialog->move(0,0);
                     m_progressDialog->show();
                     m_progressDialogExists = true;
@@ -977,8 +977,8 @@ KDE_EXPORT void KRsync::slotSetup()
 
 	m_configDialog->show();
 
-	connect (m_configDialog, TQT_SIGNAL(okClicked()), TQT_SLOT(slotSetupOK()));
-	connect (m_configDialog, TQT_SIGNAL(cancelClicked()), TQT_SLOT(slotSetupCancelled()));
+	connect (m_configDialog, TQ_SIGNAL(okClicked()), TQ_SLOT(slotSetupOK()));
+	connect (m_configDialog, TQ_SIGNAL(cancelClicked()), TQ_SLOT(slotSetupCancelled()));
 }
 
 KDE_EXPORT void KRsync::slotSetupOK()
