@@ -47,7 +47,7 @@ namespace KSpell2
     class KDE_EXPORT Broker : public TQObject,
                    public TDEShared
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         typedef TDESharedPtr<Broker> Ptr;
         /**
