@@ -39,7 +39,7 @@ namespace KSpell2
      */
     class KDE_EXPORT Client : public TQObject
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         Client( TQObject *parent = 0, const char *name=0 );
 
