@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C++; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* tdespell2 - adopted from Enchant
  * Copyright (C) 2003 Dom Lachowicz
  * Copyright (C) 2004 Zack Rusin <zack@kde.org>
@@ -55,6 +54,9 @@ typedef struct str_ispell_map
 } IspellMap;
 
 static const char *ispell_dirs [] = {
+#ifdef ISPELL_LIBDIR
+	ISPELL_LIBDIR,
+#else
 	"/usr/" SYSTEM_LIBDIR "/ispell",
 	"/usr/lib/ispell",
 	"/usr/local/" SYSTEM_LIBDIR "/ispell",
@@ -62,6 +64,7 @@ static const char *ispell_dirs [] = {
 	"/usr/local/share/ispell",
 	"/usr/share/ispell",
 	"/usr/pkg/lib",
+#endif
 	0
 };
 static const IspellMap ispell_map [] = {
