@@ -219,12 +219,12 @@ void HighContrastStyle::setColorsByState (TQPainter* p, const TQColorGroup& cg,
 
 	if ((flags & Style_Enabled) && (flags & highlight))
 	{
-		p->setPen  (TQPen (cg.highlightedText(), basicLineWidth, flags & Style_Enabled ? Qt::SolidLine : Qt::DotLine));
+		p->setPen  (TQPen (cg.highlightedText(), basicLineWidth, flags & Style_Enabled ? TQt::SolidLine : TQt::DotLine));
 		p->setBackgroundColor (cg.highlight());
 	}
 	else
 	{
-		p->setPen  (TQPen (fg, basicLineWidth, flags & Style_Enabled ? Qt::SolidLine : Qt::DotLine));
+		p->setPen  (TQPen (fg, basicLineWidth, flags & Style_Enabled ? TQt::SolidLine : TQt::DotLine));
 		p->setBackgroundColor (bg);
 	}
 
@@ -253,7 +253,7 @@ void HighContrastStyle::drawRoundRect (TQPainter* p, TQRect r, int offset, bool
 		addOffset (&r3, lineWidth);
 
 		p->save();
-		p->setPen (Qt::NoPen);
+		p->setPen (TQt::NoPen);
 		if (filled)
 			p->fillRect (r3, p->backgroundColor());
 		p->drawRect (r3);
@@ -371,9 +371,9 @@ void HighContrastStyle::drawPrimitive (PrimitiveElement pe,
 		case PE_FocusRect: {
 			p->save();
 			p->setBrush (TQBrush ());
-			p->setPen (TQPen (cg.highlight(), basicLineWidth, Qt::SolidLine));
+			p->setPen (TQPen (cg.highlight(), basicLineWidth, TQt::SolidLine));
 			drawRoundRect (p, r, basicLineWidth, false);
-			p->setPen (TQPen (cg.highlightedText(), basicLineWidth, Qt::DashLine));
+			p->setPen (TQPen (cg.highlightedText(), basicLineWidth, TQt::DashLine));
 			drawRoundRect (p, r, basicLineWidth, false);
 			p->restore();
 			break;
@@ -472,7 +472,7 @@ void HighContrastStyle::drawPrimitive (PrimitiveElement pe,
 
 		
 		case PE_ProgressBarChunk: {
-			p->fillRect (r, Qt::color1);
+			p->fillRect (r, TQt::color1);
 			break;
 		}
 
@@ -506,7 +506,7 @@ void HighContrastStyle::drawPrimitive (PrimitiveElement pe,
 			break;
 		}
 		case PE_IndicatorMask: {
-			p->fillRect (r, Qt::color1);
+			p->fillRect (r, TQt::color1);
 			break;
 		}
 		case PE_CheckMark: {
@@ -535,10 +535,10 @@ void HighContrastStyle::drawPrimitive (PrimitiveElement pe,
 			break;
 		}
 		case PE_ExclusiveIndicatorMask: {
-			p->fillRect (r, Qt::color0);
-			p->setBackgroundColor (Qt::color1);
-			p->setPen (Qt::NoPen);
-			p->setBrush (Qt::color1);
+			p->fillRect (r, TQt::color0);
+			p->setBackgroundColor (TQt::color1);
+			p->setPen (TQt::NoPen);
+			p->setBrush (TQt::color1);
 			p->drawEllipse (r);
 			break;
 		}
@@ -551,7 +551,7 @@ void HighContrastStyle::drawPrimitive (PrimitiveElement pe,
 			setColorsButton (p, cg, flags);
 			p->fillRect (r, p->backgroundColor());
 			
-			p->setPen (TQPen (p->pen().color(), 1, Qt::DashLine));
+			p->setPen (TQPen (p->pen().color(), 1, TQt::DashLine));
 			if (flags & Style_Horizontal)
 				p->drawLine (r.center().x(), r.top(), r.center().x(), r.bottom());
 			else
@@ -713,7 +713,7 @@ void HighContrastStyle::drawTDEStylePrimitive (TDEStylePrimitive kpe,
 		{
 			setColorsButton (p, cg);
 			p->fillRect (r, p->backgroundColor());
-			p->setBrush (TQBrush (p->pen().color(), Qt::BDiagPattern));
+			p->setBrush (TQBrush (p->pen().color(), TQt::BDiagPattern));
 			drawRoundRect (p, r);
 			break;
 		}
@@ -784,7 +784,7 @@ void HighContrastStyle::drawTDEStylePrimitive (TDEStylePrimitive kpe,
 }
 
 
-void HighContrastStyle::drawControl (TQ_ControlElement element,
+void HighContrastStyle::drawControl (ControlElement element,
 								TQPainter *p,
 								const TQStyleControlElementData &ceData,
 								ControlElementFlags elementFlags,
@@ -1133,14 +1133,14 @@ void HighContrastStyle::drawControl (TQ_ControlElement element,
 
 					// Draw the pixmap
 					if ( pixmap->depth() == 1 )
-						p->setBackgroundMode( Qt::OpaqueMode );
+						p->setBackgroundMode( TQt::OpaqueMode );
 
 					int diffw = ( ( w - pixmap->width() ) / 2 )
 									+ ( ( w - pixmap->width() ) % 2 );
 					p->drawPixmap( x+diffw, y+itemFrame, *pixmap );
 
 					if ( pixmap->depth() == 1 )
-						p->setBackgroundMode( Qt::TransparentMode );
+						p->setBackgroundMode( TQt::TransparentMode );
 				}
 			}
 
@@ -1162,7 +1162,7 @@ void HighContrastStyle::drawControl (TQ_ControlElement element,
 	}
 }
 
-void HighContrastStyle::drawControlMask (TQ_ControlElement element,
+void HighContrastStyle::drawControlMask (ControlElement element,
 										TQPainter *p,
 										const TQStyleControlElementData &ceData,
 										ControlElementFlags elementFlags,
@@ -1207,7 +1207,7 @@ static TQListViewItem* nextVisibleSibling(TQListViewItem* item)
     return sibling;
 }
 
-void HighContrastStyle::drawComplexControl (TQ_ComplexControl control,
+void HighContrastStyle::drawComplexControl (ComplexControl control,
 									TQPainter *p,
 									const TQStyleControlElementData &ceData,
 									ControlElementFlags elementFlags,
@@ -1262,12 +1262,12 @@ void HighContrastStyle::drawComplexControl (TQ_ComplexControl control,
 			setColorsButton (p, cg, flags);
 			// Draw arrows if required
 			if (controls & SC_SpinWidgetDown) {
-				TQRect r2 = TQStyle::visualRect (querySubControlMetrics ((TQ_ComplexControl)CC_SpinWidget, ceData, elementFlags, SC_SpinWidgetDown, TQStyleOption::Default, widget), ceData, elementFlags);
+				TQRect r2 = TQStyle::visualRect (querySubControlMetrics ((ComplexControl)CC_SpinWidget, ceData, elementFlags, SC_SpinWidgetDown, TQStyleOption::Default, widget), ceData, elementFlags);
 				drawRoundRect (p, r2);
 				drawArrow (p, r2, PE_SpinWidgetDown, 2*basicLineWidth);
 			}
 			if (controls & SC_SpinWidgetUp) {
-				TQRect r2 = TQStyle::visualRect (querySubControlMetrics ((TQ_ComplexControl)CC_SpinWidget, ceData, elementFlags, SC_SpinWidgetUp, TQStyleOption::Default, widget), ceData, elementFlags);
+				TQRect r2 = TQStyle::visualRect (querySubControlMetrics ((ComplexControl)CC_SpinWidget, ceData, elementFlags, SC_SpinWidgetUp, TQStyleOption::Default, widget), ceData, elementFlags);
 				drawRoundRect (p, r2);
 				drawArrow (p, r2, PE_SpinWidgetUp, 2*basicLineWidth);
 			}
@@ -1490,7 +1490,7 @@ void HighContrastStyle::drawComplexControl (TQ_ComplexControl control,
 	}
 }
 
-void HighContrastStyle::drawComplexControlMask(TQ_ComplexControl c,
+void HighContrastStyle::drawComplexControlMask(ComplexControl c,
 											   TQPainter *p,
 											   const TQStyleControlElementData &ceData,
 											   const ControlElementFlags elementFlags,
@@ -1535,7 +1535,7 @@ void HighContrastStyle::drawItem( TQPainter *p,
 	p->restore();
 }
 
-TQRect HighContrastStyle::querySubControlMetrics( TQ_ComplexControl control,
+TQRect HighContrastStyle::querySubControlMetrics( ComplexControl control,
 								  const TQStyleControlElementData &ceData,
 								  ControlElementFlags elementFlags,
 								  SubControl subcontrol,
